from bg4h.helpers import DeprecatedAttr


class BgMain: 

    class RecOperaciones:
        _tbl = 'REGOPERACIONES'
        soc = 'REGOPERACIONES1'
        worker = 'REGOPERACIONES2'
        date = 'REGOPERACIONES3'
        hour = 'REGOPERACIONES4'
        location = 'REGOPERACIONES5'
        action = 'REGOPERACIONES6'
        key = 'REGOPERACIONES7'
        desc = 'REGOPERACIONES8'
        auto_numeric_line = 'REGOPERACIONES9'
        numeric_index = 'REGOPERACIONES10'
    class RegSystem:
        _tbl = 'REGSYSTEM'
        action_id = 'REGSYSTEM1'
        file_id = 'REGSYSTEM2'
        register_id = 'REGSYSTEM3'
        property_id = 'REGSYSTEM4'
        value_1 = 'REGSYSTEM5'
        value_2 = 'REGSYSTEM6'

    class CajasTpv:
        _tbl = 'TCAJASTPV'
        code = 'TCAJASTPV1'
        name = 'TCAJASTPV2'
        default_payment_type = 'TCAJASTPV3'
        warehouse_out = 'TCAJASTPV4'
        currency = 'TCAJASTPV5'
        language = 'TCAJASTPV6'
        # works_only_with_articles_from_families = 'TCAJASTPV7' #TODO check this out
        # WorksOnlyWithArticlesFromFamiliescodes = 'TCAJASTPV8' #TODO check this out
        # DontWorksWithArticlesFromFamilies = 'TCAJASTPV9' #TODO check this out
        # DontWorksWithArticlesFromFamllies = 'TCAJASTPV10' #TODO check this out
        normal_ticket_sn = 'TCAJASTPV11'
        normal_ticket_graphic_format = 'TCAJASTPV12'
        normal_ticket_format = 'TCAJASTPV13'
        normal_ticket_printer_model = 'TCAJASTPV14'
        normal_ticket_output_port = 'TCAJASTPV15'
        special_ticket_sn = 'TCAJASTPV16'
        special_ticket_graphic_format = 'TCAJASTPV17'
        special_ticket_format = 'TCAJASTPV18'
        special_ticket_printer_model = 'TCAJASTPV19'
        special_ticket_output_port = 'TCAJASTPV20'
        invoice_ticket_sn = 'TCAJASTPV21'
        invoice_ticket_graphic_format = 'TCAJASTPV22'
        invoice_ticket_format = 'TCAJASTPV23'
        invoice_ticket_printer_model = 'TCAJASTPV24'
        invoice_ticket_output_port = 'TCAJASTPV25'
        delivery_note_ticket_sn = 'TCAJASTPV26'
        delivery_note_ticket_graphic_format = 'TCAJASTPV27'
        delivery_note_ticket_format = 'TCAJASTPV28'
        delivery_note_ticket_printer_model = 'TCAJASTPV29'
        delivery_note_ticket_output_port = 'TCAJASTPV30'
        special_delivery_note_ticket_sn = 'TCAJASTPV31'
        special_delivery_note_ticket_graphic_format = 'TCAJASTPV32'
        special_delivery_note_ticket_format = 'TCAJASTPV33'
        special_delivery_note_ticket_printer_model = 'TCAJASTPV34'
        special_delivery_note_ticket_output_port = 'TCAJASTPV35'
        other_movements_graphic_format = 'TCAJASTPV36'
        other_movements_format = 'TCAJASTPV37'
        other_movements_printer_model = 'TCAJASTPV38'
        other_movements_output_port = 'TCAJASTPV39'
        voucher_graphic_format = 'TCAJASTPV40'
        voucher_format = 'TCAJASTPV41'
        voucher_printer_model = 'TCAJASTPV42'
        voucher_output_port = 'TCAJASTPV43'
        ticket_footer_text = 'TCAJASTPV44'
        user_decide_print = 'TCAJASTPV45'
        print_ticket_on_end = 'TCAJASTPV46'
        serial_number = 'TCAJASTPV47'
        lot_number = 'TCAJASTPV48'
        sizes = 'TCAJASTPV49'
        packaging_possesion = 'TCAJASTPV50'
        control_over_repairs = 'TCAJASTPV51'
        colors = 'TCAJASTPV52'
        warranty = 'TCAJASTPV53'
        expiration = 'TCAJASTPV54'
        price_base_taxable = 'TCAJASTPV55'
        price_tax_included = 'TCAJASTPV56'
        price_tax_included_breakdown = 'TCAJASTPV57'
        cashier_without_cashier = 'TCAJASTPV58'
        cashier_one_per_turn = 'TCAJASTPV59'
        cashier_identify_everytime = 'TCAJASTPV60'
        agent_without_agent = 'TCAJASTPV61'
        agent_one_per_turn = 'TCAJASTPV62'
        agent_identify_everytime = 'TCAJASTPV63'
        drawer_model = 'TCAJASTPV64'
        drawer_port = 'TCAJASTPV65'
        display_model = 'TCAJASTPV66'
        display_port = 'TCAJASTPV67'
        text_between_tickets = 'TCAJASTPV68'
        activation_time = 'TCAJASTPV69'
        mobile = 'TCAJASTPV70'
        scanner_1_model = 'TCAJASTPV71'
        scanner_1_port = 'TCAJASTPV72'
        scanner_2_model = 'TCAJASTPV73'
        scanner_2_port = 'TCAJASTPV74'
        magnetic_card_model = 'TCAJASTPV75'
        magnetic_card_port = 'TCAJASTPV76'
        weight_scale_model = 'TCAJASTPV77'
        weight_scale_port = 'TCAJASTPV78'
        touch_screen_port = 'TCAJASTPV79'
        touch_screen_model = 'TCAJASTPV80'
        ticket_counter = 'TCAJASTPV81'
        anagram_file = 'TCAJASTPV82'
        big_icons_charges = 'TCAJASTPV83'
        cash_client_code = 'TCAJASTPV84'
        cash_client_name = 'TCAJASTPV85'
        enable_firm = 'TCAJASTPV86'
        dont_round_prices_with_tax = 'TCAJASTPV87'
        document_types_used = 'TCAJASTPV88'
        refund_series = 'TCAJASTPV89'
        simple_invoice_sn = 'TCAJASTPV90'
        simple_invoice_format = 'TCAJASTPV91'
        simple_invoice_printer_model = 'TCAJASTPV92'
        simple_invoice_printer_port = 'TCAJASTPV93'
        simple_invoice_graphic_format = 'TCAJASTPV94'
        show_on_sell_discount = 'TCAJASTPV98'
        show_on_sell_line_counter_value = 'TCAJASTPV99'
        dont_switch_to_ticket_on_print = 'TCAJASTPV100'
  

    class CategoriasProfesionales:
        _tbl = 'TCATEGORIASPROFESIONALES'
        code = 'TCATEGORIASPROFESIONALES1'
        name = 'TCATEGORIASPROFESIONALES2'

    class ConceptosRectificacion:
        _tbl = 'TCONCEPTOSRECTIFICACION'
        code = 'TCONCEPTOSRECTIFICACION1'
        desc = 'TCONCEPTOSRECTIFICACION2'
        type = 'TCONCEPTOSRECTIFICACION3'
  
    class CostesPersonal :
        _tbl = 'TCOSTESPERSONAL'
        hour_type = 'TCOSTESPERSONAL1'
        cost = 'TCOSTESPERSONAL2'
        price = 'TCOSTESPERSONAL3'
        worker = 'TCOSTESPERSONAL4'
        price_currency = 'TCOSTESPERSONAL5'
        cost_currency = 'TCOSTESPERSONAL6'
  

    class CostePrecioHoraCatProf :
        _tbl = 'TCOSTEPRECIOHORACATPROF'
        hour_type = 'TCOSTEPRECIOHORACATPROF1'
        cost = 'TCOSTEPRECIOHORACATPROF2'
        price = 'TCOSTEPRECIOHORACATPROF3'
        professional_cat = 'TCOSTEPRECIOHORACATPROF4'
        currency = 'TCOSTEPRECIOHORACATPROF9'
  
    class DatosDeControl :
        article_tax_code = DeprecatedAttr("TDATOSDECONTROL40","article_tax_code", "default_article_tax_code")
        _tbl = 'TDATOSDECONTROL'
        code = 'TDATOSDECONTROL1'
        name = 'TDATOSDECONTROL2'
        currency_base = 'TDATOSDECONTROL3'
        taxes_per_article = 'TDATOSDECONTROL4'
        taxes_per_budget_doc = 'TDATOSDECONTROL5'
        financial_year = 'TDATOSDECONTROL6'
        default_sell_doc_tax_code = 'TDATOSDECONTROL14'
        default_client_agrarian_tax_code = 'TDATOSDECONTROL15'
        default_client_exempt_tax_code = 'TDATOSDECONTROL16'
        default_client_eu_tax_code = 'TDATOSDECONTROL17'
        default_provider_tax_code = 'TDATOSDECONTROL18'
        default_provider_agrarian_tax_code = 'TDATOSDECONTROL19'
        default_provider_exempt_tax_code = 'TDATOSDECONTROL20'
        default_provider_eu_tax_code = 'TDATOSDECONTROL21'
        default_sell_doc_special_tax_code = 'TDATOSDECONTROL35'
        default_article_tax_code = 'TDATOSDECONTROL40'
        
        default_family_code = 'TDATOSDECONTROL42'
        default_account_cash = 'TDATOSDECONTROL58'
        default_warehouse_purchases = 'TDATOSDECONTROL59'
        default_warehouse_sells = 'TDATOSDECONTROL60'

        default_client_general_agrarian_tax_code = 'TDATOSDECONTROL62'
        default_provider_general_agrarian_tax_code = 'TDATOSDECONTROL63'




        payment_method_code = 'TDATOSDECONTROL67'
        default_account_exchange_differences = 'TDATOSDECONTROL80'
        default_account_financialIncome = 'TDATOSDECONTROL82'
        default_currency = 'TDATOSDECONTROL85'
        default_account_invoices = 'TDATOSDECONTROL87'
        calculate_margin_puc = 'TDATOSDECONTROL115'
        calculate_margin_pmp = 'TDATOSDECONTROL116'
        worker_tax_code = 'TDATOSDECONTROL122'
        client_without_record_code = 'TDATOSDECONTROL123'
        client_without_record_name = 'TDATOSDECONTROL124'
        default_payment_method = 'TDATOSDECONTROL127'
        street = 'TDATOSDECONTROL129'
        zip_code = 'TDATOSDECONTROL130'
        city = 'TDATOSDECONTROL131'
        province = 'TDATOSDECONTROL132'
        country = 'TDATOSDECONTROL133'
        phone = 'TDATOSDECONTROL134'
        fax = 'TDATOSDECONTROL135'
        email = 'TDATOSDECONTROL136'
        nif = 'TDATOSDECONTROL138'
        calculate_margin_last_price = 'TDATOSDECONTROL160'
        margin_materials = 'TDATOSDECONTROL213'

    class Divisas:
        _tbl = 'TDIVISAS'
        code = 'TDIVISAS1'
        name = 'TDIVISAS2'
        fix_unique_counter_value = 'TDIVISAS3'
        round_decimales_values = 'TDIVISAS4'
        round_eecimales_prices = 'TDIVISAS5'
        change_value = 'TDIVISAS6'
        round_decimales_additionals = 'TDIVISAS7'
        symbol_pre = 'TDIVISAS8'
        symbol_currency = 'TDIVISAS9'
        round_decimals_values_intermediate = 'TDIVISAS14'
  
    class FormasPago:
        _tbl = 'TFORMASPAGO'
        code = 'TFORMASPAGO1'
        name = 'TFORMASPAGO2'
        payment_type_code = 'TFORMASPAGO3'
        expiration_number = 'TFORMASPAGO4'
        recharge_by_post_ponement = 'TFORMASPAGO5'
        recharge_by_post_ponement_value = 'TFORMASPAGO6'
        recharge_by_post_ponement_period = 'TFORMASPAGO7'
        dont_print_expiration_on_bills = 'TFORMASPAGO8'
        remittable = 'TFORMASPAGO9'
        printable = 'TFORMASPAGO10'
        payment_method = 'TFORMASPAGO11'
        adjust_expirement_in_every_bill = 'TFORMASPAGO12'
        language_description_2 = 'TFORMASPAGO13'
        language_description_3 = 'TFORMASPAGO14'
        language_description_4 = 'TFORMASPAGO15'
        language_description_5 = 'TFORMASPAGO16'
        reserved_1 = 'TFORMASPAGO17'
        reserved_2 = 'TFORMASPAGO18'
        reserved_3 = 'TFORMASPAGO19'
        reserved_4 = 'TFORMASPAGO20'
        reserved_5 = 'TFORMASPAGO21'
        reserved_6 = 'TFORMASPAGO22'
        reserved_7 = 'TFORMASPAGO23'
        returned_period = 'TFORMASPAGO24'
        currency = 'TFORMASPAGO25'
        payment_form_edi_communications = 'TFORMASPAGO26'
        observations = 'TFORMASPAGO27'
        money_order_bank_receipt = 'TFORMASPAGO28'
        iso_alfa_code = 'TFORMASPAGO29'
        skip_late_payment_law = 'TFORMASPAGO30'
        use_on_b2c = 'TFORMASPAGO31'
        use_on_b2b = 'TFORMASPAGO32'
        portal_format_b2b_code = 'TFORMASPAGO33'
        portal_format_b2b = 'TFORMASPAGO34'
  
    class HorasExtras:
        _tbl = 'THORASEXTRAS'
        day_text = 'THORASEXTRAS1'
        hours = 'THORASEXTRAS2'
        worker = 'THORASEXTRAS3'
        day_number = 'THORASEXTRAS5'
  
    class Mailing:
        _tbl = 'TMAILING'
        Mailingcode = 'TMAILING1'
        name = 'TMAILING2'
        nif = 'TMAILING3'
        street = 'TMAILING4'
        zip_code = 'TMAILING7'
        city = 'TMAILING8'
        province = 'TMAILING9'
        country = 'TMAILING10'
        at_attention_of = 'TMAILING11'
        phone_1 = 'TMAILING12'
        phone_2 = 'TMAILING13'
        fax_1 = 'TMAILING14'
        fax_2 = 'TMAILING15'
        email_1 = 'TMAILING16'
        email_2 = 'TMAILING17'
        is_client = 'TMAILING18'
        is_provider = 'TMAILING19'
        is_comission_agent = 'TMAILING20'
        is_worker = 'TMAILING21'
        is_carrier = 'TMAILING22'
        send_nothing = 'TMAILING23'
        send_letters = 'TMAILING24'
        send_fax = 'TMAILING25'
        send_calls = 'TMAILING26'
        send_mails = 'TMAILING27'
        phone_group_code = 'TMAILING28'
        observations = 'TMAILING29'
  
    class MailingContactos:
        _tbl = 'TMAILINGCONTACTOS'
        department = 'TMAILINGCONTACTOS1'
        name = 'TMAILINGCONTACTOS2'
        phone = 'TMAILINGCONTACTOS3'
        fax = 'TMAILINGCONTACTOS4'
        mail = 'TMAILINGCONTACTOS5'
        mailing_code = 'TMAILINGCONTACTOS6'
        id = 'TMAILINGCONTACTOS7'
        position = 'TMAILINGCONTACTOS10'

    class MailingMasDirecciones:
        _tbl = 'TMAILINGMASDIRECCIONES'
        numeric_index = 'TMAILINGMASDIRECCIONES1'
        street = 'TMAILINGMASDIRECCIONES2'
        zip_code = 'TMAILINGMASDIRECCIONES3'
        city = 'TMAILINGMASDIRECCIONES4'
        province = 'TMAILINGMASDIRECCIONES5'
        shipping_cost_zone = 'TMAILINGMASDIRECCIONES6'
        desc = 'TMAILINGMASDIRECCIONES7'
        KM = 'TMAILINGMASDIRECCIONES8'
        mailing_code = 'TMAILINGMASDIRECCIONES9'
        country = 'TMAILINGMASDIRECCIONES10'
        auto_numeric_line = 'TMAILINGMASDIRECCIONES11'
        department = 'TMAILINGMASDIRECCIONES12'
        contact_name = 'TMAILINGMASDIRECCIONES13'
        ean_code_edi_communications = 'TMAILINGMASDIRECCIONES14'
        phone = 'TMAILINGMASDIRECCIONES15'
        fax = 'TMAILINGMASDIRECCIONES16'
        email = 'TMAILINGMASDIRECCIONES17'
  
    class MediosTransporte:
        _tbl = 'TMEDIOSTRANSPORTE'
        code = 'TMEDIOSTRANSPORTE1'
        name = 'TMEDIOSTRANSPORTE2'
        ask_for_code = 'TMEDIOSTRANSPORTE3'
        dont_ask_for_code = 'TMEDIOSTRANSPORTE4'
  
    class Personal:
        _tbl = 'TPERSONAL'
        code = 'TPERSONAL1'
        name = 'TPERSONAL2'
        address = 'TPERSONAL3'
        zip_code = 'TPERSONAL4'
        city = 'TPERSONAL5'
        province = 'TPERSONAL6'
        country = 'TPERSONAL7'
        phone = 'TPERSONAL8'
        nif = 'TPERSONAL9'
        number_ss = 'TPERSONAL10'
        birth_day = 'TPERSONAL11'
        birth_place = 'TPERSONAL12'
        marriage_status = 'TPERSONAL13'
        number_of_childs = 'TPERSONAL14'
        proffesional_cat_code = 'TPERSONAL15'
        contract_type_code = 'TPERSONAL16'
        studies_level = 'TPERSONAL17'
        delegation_code = 'TPERSONAL18'
        section_code = 'TPERSONAL19'
        company_join_date = 'TPERSONAL20'
        contract_start = 'TPERSONAL21'
        contract_end = 'TPERSONAL22'
        company_leave_date = 'TPERSONAL23'
        active = 'TPERSONAL24'
        inactive = 'TPERSONAL25'
        app_user = 'TPERSONAL26'
        income_bank_name = 'TPERSONAL27'
        income_bank_account = 'TPERSONAL28'
        observations = 'TPERSONAL32'
        daily_hours_bool = 'TPERSONAL33'
        daily_hours = 'TPERSONAL34'
        soc_login = 'TPERSONAL44'
        email = 'TPERSONAL46'
        soc_belongs_to_code = 'TPERSONAL69'
        soc_belongs_to_name = 'TPERSONAL70'
        password = 'TPERSONAL71'
        mailing_code = 'TPERSONAL75'
        agent_code = 'TPERSONAL90'
        income_bank_iban = 'TPERSONAL96'
        depends_on = 'TPERSONAL105'
        daily_hours_variable_bool = 'TPERSONAL111'
        last_order_doc_code = 'TPERSONAL112'
        work_team = 'TPERSONAL120'
        work_team_in_charge = 'TPERSONAL121'
        ware_house_code = 'TPERSONAL125'
        email_2 = 'TPERSONAL164'
        income_bank_bic ='TPERSONAL175'
  
    class SeccionesSociedad:
        _tbl = 'TSECCIONESSOCIEDAD'
        code = 'TSECCIONESSOCIEDAD1'
        desc = 'TSECCIONESSOCIEDAD2'
  
    class Tareas:
        _tbl = 'TTAREAS'
        code = 'TTAREAS1'
        desc = 'TTAREAS2'
        observations = 'TTAREAS5'
        group = 'TTAREAS6'
        data_type = 'TTAREAS8'
        data_length = 'TTAREAS9'
        data_decimals ='TTAREAS10'
        data_default_intial_value = 'TTAREAS12'
        data_default_value = 'TTAREAS17'
    
  
    class TiposCobro:
        _tbl = 'TTIPOSCOBRO'
        code = 'TTIPOSCOBRO1'
        desc = 'TTIPOSCOBRO2'
        account = 'TTIPOSCOBRO16'
  
    class TiposImpuestosRepercutidos:
        _tbl = 'TTIPOSIMPUESTOSREPERCUTIDOS'
        code = 'TTIPOSIMPUESTOSREPERCUTIDOS1'
        desc = 'TTIPOSIMPUESTOSREPERCUTIDOS2'
        percentage = 'TTIPOSIMPUESTOSREPERCUTIDOS3'
        code_pgc = 'TTIPOSIMPUESTOSREPERCUTIDOS4'
        percentage_surcharge_equivalence = 'TTIPOSIMPUESTOSREPERCUTIDOS5'
        code_pgc_surcharge_equivalence = 'TTIPOSIMPUESTOSREPERCUTIDOS6'
        classification = 'TTIPOSIMPUESTOSREPERCUTIDOS7'
        iso_alva_code = 'TTIPOSIMPUESTOSREPERCUTIDOS8'
        province_code = 'TTIPOSIMPUESTOSREPERCUTIDOS9'
        country_code = 'TTIPOSIMPUESTOSREPERCUTIDOS10'
  
    class Vacaciones:
        _tbl = 'TVACACIONES'
        date_start = 'TVACACIONES1'
        date_end = 'TVACACIONES2'
        worker = 'TVACACIONES3'
        id = 'TVACACIONES4'
        days = 'TVACACIONES5'
        index = 'TVACACIONES6'
  
    class OtrosVacaciones:
        _tbl = 'TOTROSVACACIONES'
        date = 'TOTROSVACACIONES1'
        days = 'TOTROSVACACIONES2'
        type = 'TOTROSVACACIONES3'
        hours = 'TOTROSVACACIONES4'
        observations = 'TOTROSVACACIONES5'
        worker = 'TOTROSVACACIONES6'

    class OtrasIncidenciasPersonal:
        _tbl  = 'TOTRASINCIDENCIASPERSONAL'
        code = 'TOTRASINCIDENCIASPERSONAL1'
        desc = 'TOTRASINCIDENCIASPERSONAL2'
        reason = 'TOTRASINCIDENCIASPERSONAL3'





    class Vencimientos:
        _tbl = 'TVENCIMIENTOS'
        days = 'TVENCIMIENTOS2'
        percentage = 'TVENCIMIENTOS3'
        payment_method_code = 'TVENCIMIENTOS4'

    class Familias:
        _tbl = 'TFAMILIAS'
        code = 'TFAMILIAS1'
        name = 'TFAMILIAS2'
        pgc_code_purchases = 'TFAMILIAS3'
        pgc_code_devolutions = 'TFAMILIAS4'
        pgc_code_sells = 'TFAMILIAS5'
        show_observations = 'TFAMILIAS9',
        observations = 'TFAMILIAS11'
        free_field_1 = 'TFAMILIAS13'
        free_field_2 = 'TFAMILIAS14'
        free_field_3 = 'TFAMILIAS15'
  
    class Subfamilias:
        _tbl = 'TSUBFAMILIAS'
        code = 'TSUBFAMILIAS1'
        name = 'TSUBFAMILIAS2'
        increment_percentage_per_unit = 'TSUBFAMILIAS3'
        free_field_1 = 'TSUBFAMILIAS4'
        free_field_2 = 'TSUBFAMILIAS5'
        free_field_3 = 'TSUBFAMILIAS6'
        default_DiscountPercentage = 'TSUBFAMILIAS7'
        show_observations = "TSUBFAMILIAS9",
        observations = 'TSUBFAMILIAS11'
        pgc_code_purchases = 'TSUBFAMILIAS65'
        pgc_code_devolutions = 'TSUBFAMILIAS66'
        pgc_code_sells = 'TSUBFAMILIAS67'

    class Grupos:
        _tbl = 'TGRUPOS'
        code = 'TGRUPOS1'
        name = 'TGRUPOS2'
        free_field_1 = 'TGRUPOS4'
        free_field_2 = 'TGRUPOS5'
        free_field_3 = 'TGRUPOS'
        pgc_code_purchases = 'TGRUPOS62'
        pgc_code_devolutions = 'TGRUPOS63'
        pgc_code_sells = 'TGRUPOS64'
        
    class Roles:
        _tbl = 'TROLES'
        id = 'TROLES1'
        name = 'TROLES2'
        desc = 'TROLES3'
        permission_level = 'TROLES4'
  
    class RolesUsuarios:
        _tbl = 'TROLESUSUARIOS'
        id = 'TROLESUSUARIOS1'
        role_id = 'TROLESUSUARIOS2'
        user_code = 'TROLESUSUARIOS3'
  
